//---------------------------------------------------------------------------
//    $Id: mesh_worker_info.cc 24272 2011-09-06 16:01:55Z kanschat $
//    Version: $Name$
//
//    Copyright (C) 2009, 2010, 2011 by the deal.II authors
//
//    This file is subject to QPL and may not be  distributed
//    without copyright and license information. Please refer
//    to the file deal.II/doc/license.html for the  text  and
//    further information on this license.
//
//---------------------------------------------------------------------------

#include <deal.II/lac/vector.h>
#include <deal.II/lac/block_vector.h>
#include <deal.II/lac/petsc_vector.h>
#include <deal.II/lac/petsc_block_vector.h>
#include <deal.II/lac/trilinos_vector.h>
#include <deal.II/lac/trilinos_block_vector.h>

#include <deal.II/meshworker/dof_info.templates.h>
#include <deal.II/meshworker/integration_info.templates.h>

DEAL_II_NAMESPACE_OPEN

// explicit instantiations
#include "mesh_worker_info.inst"


DEAL_II_NAMESPACE_CLOSE

